package com.xx.merchanthbh.data.http

import com.xx.merchanthbh.data.http.respons.ActivityCenterBean
import com.xx.merchanthbh.data.http.respons.AdvertisingBean
import com.xx.merchanthbh.data.http.respons.AppealTypeBean
import com.xx.merchanthbh.data.http.respons.AssistantInformationBean
import com.xx.merchanthbh.data.http.respons.BoothBean
import com.xx.merchanthbh.data.http.respons.CategoryBean
import com.xx.merchanthbh.data.http.respons.ConsultationInformationBean
import com.xx.merchanthbh.data.http.respons.Filebean
import com.xx.merchanthbh.data.http.respons.JobInformationBean
import com.xx.merchanthbh.data.http.respons.MerchantBean
import com.xx.merchanthbh.data.http.respons.MerchantPointBean
import com.xx.merchanthbh.data.http.respons.MessageBean
import com.xx.merchanthbh.data.http.respons.OrderBean
import com.xx.merchanthbh.data.http.respons.OrderDetailBean
import com.xx.merchanthbh.data.http.respons.RegisterBean
import com.xx.merchanthbh.data.http.respons.UserInfoBean
import io.reactivex.rxjava3.core.Observable
import me.goldze.mvvmhabit.http.BasePageResponse
import me.goldze.mvvmhabit.http.BaseResponse
import okhttp3.MultipartBody
import okhttp3.RequestBody
import retrofit2.http.Body
import retrofit2.http.GET
import retrofit2.http.Headers
import retrofit2.http.Multipart
import retrofit2.http.POST
import retrofit2.http.Part
import retrofit2.http.Path
import retrofit2.http.Query


interface ApiService {

    /**
     * 登陆
     */
    @Headers("Content-type:application/json")
    @POST("app/user/login")
    open fun Login(@Body requestBody: RequestBody): Observable<BaseResponse<String>>

    /**
     * 修改密码
     */
    @Headers("Content-type:application/json")
    @POST("app/user/update-password")
    open fun ChangePwd(@Body requestBody: RequestBody): Observable<BaseResponse<String>>

    /**
     * 忘记密码
     */
    @Headers("Content-type:application/json")
    @POST("app/user/forget-password")
    open fun ForegetPwd(@Body requestBody: RequestBody): Observable<BaseResponse<String>>

    /**
     * 设置密码
     */
    @Headers("Content-type:application/json")
    @POST("app/user/set-password")
    open fun SetPwd(@Body requestBody: RequestBody): Observable<BaseResponse<String>>

    /**
     * 更改手机号
     */
    @Headers("Content-type:application/json")
    @POST("app/user/update-phone")
    open fun ChangePhone(@Body requestBody: RequestBody): Observable<BaseResponse<String>>

    /**
     * 获取验证码
     */
    @Headers("Content-type:application/json")
    @GET("app/user/send-verification-code")
    open fun getCode(@Query("phone") phone: String): Observable<BaseResponse<String>>

    /**
     * 注册
     */
    @Headers("Content-type:application/json")
    @POST("app/user/register")
    open fun register(@Body requestBody: RequestBody): Observable<BaseResponse<RegisterBean>>


    /**
     * 获取用户信息
     */
    @Headers("Content-type:application/json")
    @GET("app/getInfo")
    open fun getUserInfo(): Observable<BaseResponse<UserInfoBean>>


    /**
     * 获取展位管理列表
     * status:状态 0启用 1停用
     * affiliatedCompany:所属公司
     */
    @Headers("Content-type:application/json")
    @GET("app/booth/list-all")
    open fun getBoothList(
        @Query("status") status: String,
        @Query("affiliatedCompany") affiliatedCompany: String?,
        @Query("params[merchantCount]") merchantCount:String
    ): Observable<BaseResponse<List<BoothBean>>>

    /**
     * 获取反馈类型列表(数据字典)
     */
    @Headers("Content-type:application/json")
    @GET("system/dict/data/type/appeal_type")
    open fun getAppealTypeList(
    ): Observable<BaseResponse<List<AppealTypeBean>>>
    /**
     * 店员列表查询
     */
    @Headers("Content-type:application/json")
    @GET("app/shop-person/list")
    open fun getAssistantList(
        @Query("searchWord") searchWord: String): Observable<BaseResponse<List<AssistantInformationBean>>>

    /**
     * 删除店员
     */
    @Headers("Content-type:application/json")
    @DELETE("app/shop-person/del-person/{businessId}")
    open fun deleteAssistant(
        @Path("businessId") id: String): Observable<BaseResponse<Boolean>>

    /**
     * 上传
     */
    @Multipart
    @Headers("clientType:fy_authority")
    @POST("common/uploads")
    fun upLoadFile(@Part file: List<MultipartBody.Part>): Observable<BaseResponse<List<Filebean>>>


    /**
     * 查询活动列表信息
     */
    @Headers("Content-type:application/json")
    @POST("app/activity/queryAppActivityList")
    fun getActivityList(@Body requestBody: RequestBody): Observable<BaseResponse<List<ActivityCenterBean>>>

    /**
     * 首页--APP广告位查询
     */
    @Headers("Content-type:application/json")
    @POST("app/adList/list")
    fun getADList(@Body requestBody: RequestBody): Observable<BaseResponse<List<AdvertisingBean>>>

    /**
     * 查询资讯列表信息
     */
    @Headers("Content-type:application/json")
    @POST("app/information/queryAppInformationList")
    fun getConsultationInformationList(@Body requestBody: RequestBody): Observable<BaseResponse<List<ConsultationInformationBean>>>


    /**
     * 首页--查询招聘列表信息
     */
    @Headers("Content-type:application/json")
    @POST("app/recruitment/queryAppRecruitmentList")
    fun getJobInformationList(@Body requestBody: RequestBody): Observable<BasePageResponse<JobInformationBean>>


    /**
     * 提交商户开店信息
     */
    @Headers("Content-type:application/json")
    @POST("app/merchant/online")
    fun postMerchantMsg(@Body requestBody: RequestBody): Observable<BaseResponse<Boolean>>

    /**
     * 商户线上重新申请开店
     */
    @Headers("Content-type:application/json")
    @POST("app/merchant/online/re")
    fun postReMerchantMsg(@Body requestBody: RequestBody): Observable<BaseResponse<Boolean>>

    /**
     * 修改商户开店信息
     */
    @Headers("Content-type:application/json")
    @POST("app/merchant/edit-info")
    fun postChangeMerchantMsg(@Body requestBody: RequestBody): Observable<BaseResponse<Boolean>>

    /**
     * 提交新建店员
     */
    @Headers("Content-type:application/json")
    @POST("app/shop-person/add-person")
    fun postAssistantMsg(@Body requestBody: RequestBody): Observable<BaseResponse<Boolean>>

    /**
     * APP广告位查询
     */
    @Headers("Content-type:application/json")
    @POST("app/adList/list")
    fun postADList(@Body requestBody: RequestBody): Observable<BaseResponse<List<AdvertisingBean>>>

    /**
     * 订单列表查询
     */
    @Headers("Content-type:application/json")
    @GET("app/order/merchant-app/list")
    /*订单状态 1-待付款 2-已完成 3-已关闭*/
    open fun getOderList(@Query("orderStatus") orderStatus: String): Observable<BasePageResponse<OrderBean>>

    /**
     * 消息列表查询
     */
    @Headers("Content-type:application/json")
    @GET("app/message/getMessageList")
    /*标记 0-未读 1-已读*/
    open fun getMessageList(@Query("flag") flag: String): Observable<BasePageResponse<MessageBean>>


    /**
     * 获取订单管理详细信息
     */
    @Headers("Content-type:application/json")
    @GET("app/order/merchant-app/order-info/{businessId}")
    fun getOrderDetailById(@Path("businessId") id: String?): Observable<BaseResponse<OrderDetailBean>>


    /**
     * 获取商户管理详细信息
     */
    @Headers("Content-type:application/json")
    @GET("app/merchant/{businessId}")
    fun getMerchantById(@Path("businessId") id: String?): Observable<BaseResponse<MerchantBean>>

    /**
     * 首页-商铺积分-查询
     */
    @Headers("Content-type:application/json")
    @POST("app/merchant/integral/list")
    fun getMerchantPointList(@Body requestBody: RequestBody): Observable<BaseResponse<List<MerchantPointBean>>>

    /**
     * 获取三级分类
     */
    @Headers("Content-type:application/json")
    @POST("app/commodity/category-tree")
    fun postCategory(@Body requestBody: RequestBody): Observable<BaseResponse<List<CategoryBean>>>


    /**
     * 新增商品
     */
    @Headers("Content-type:application/json")
    @POST("app/commodity/merchant-app/add")
    fun postAddProduct(@Body requestBody: RequestBody): Observable<BaseResponse<Boolean>>

    /**
     * 新增诉求管理
     */
    @Headers("Content-type:application/json")
    @POST("/app/appeal/management/merchant")
    fun postAddAppeal(@Body requestBody: RequestBody): Observable<BaseResponse<Boolean>>

}