package com.xx.merchanthbh.ui.login;

import static me.goldze.mvvmhabit.utils.Utils.Interceptor_TOKEN;

import android.app.Application;
import android.os.Bundle;
import android.text.TextUtils;
import android.text.style.ClickableSpan;
import android.view.View;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;

import com.xx.merchanthbh.R;
import com.xx.merchanthbh.data.http.requst.LoginRequest;
import com.xx.merchanthbh.data.http.respons.UserInfoBean;
import com.xx.merchanthbh.data.local.LocalData;
import com.xx.merchanthbh.data.staticdata.StaticData;
import com.xx.merchanthbh.ui.addproduct.AddProductActivity;
import com.xx.merchanthbh.ui.home.HomeActivity;
import com.xx.merchanthbh.ui.merchantenter.MerchantEnterActivity;
import com.xx.merchanthbh.ui.productmanager.ProductManagerActivity;
import com.xx.merchanthbh.ui.pwd.ForgetPwdActivity;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class LoginViewModel extends BaseViewModel<LoginRequest> {

    //用户名的绑定
    public ObservableField<String> userName = new ObservableField<>("");
    //密码的绑定
    public ObservableField<String> password = new ObservableField<>("");

    public boolean isAgree = false;

    public LoginViewModel(@NonNull Application application, LoginRequest model) {
        super(application, model);
    }

    //跳转开店页面
    public BindingCommand goMerchantEnter = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            Bundle bundle = new Bundle();
            bundle.putInt("pageStep", R.id.merchantIntroduceFragment);
            startActivity(MerchantEnterActivity.class, bundle);
        }
    });

    //跳转首页
    public BindingCommand goHome = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            startActivity(HomeActivity.class);
        }

    });

    //跳转忘记密码
    public BindingCommand forgetPwd = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            startActivity(ForgetPwdActivity.class);
        }

    });
    //登陆
    public BindingCommand login = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            if (!isAgree) {
                ToastUtils.showShort("请阅读并同意协议");
                return;

            }
            if (TextUtils.isEmpty(userName.get().toString())) {
                ToastUtils.showShort("请输入账号！");

            } else if (TextUtils.isEmpty(password.get().toString())) {
                ToastUtils.showShort("请输入密码！");
            } else {
                model.Login(userName.get().toString(), password.get().toString())
                        .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                        .doOnSubscribe(LoginViewModel.this)
                        .doOnSubscribe(new Consumer<Disposable>() {
                            @Override
                            public void accept(Disposable disposable) throws Exception {
                                showDialog("正在请求...");
                            }
                        }).subscribe(new ApiDisposableObserver<String>() {
                            @Override
                            public void onSuccess(String resultBean) {
                                //是指token
                                Interceptor_TOKEN = "Bearer " + resultBean;
                                getuserInfo();
//                                startActivity(HomeActivity.class);
                            }

                            @Override
                            public void onError(String Error) {
                                dismissDialog();
                            }

                        });
            }
        }
    });


    public void getuserInfo() {


        model.getUserInfo()
                .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                .doOnSubscribe(LoginViewModel.this)
                .doOnSubscribe(new Consumer<Disposable>() {
                    @Override
                    public void accept(Disposable disposable) throws Exception {
                    }
                }).subscribe(new ApiDisposableObserver<UserInfoBean>() {
                    @Override
                    public void onSuccess(UserInfoBean resultBean) {
//                        判断是否是店长
                        if (resultBean.getUser().getRoles().get(0).getRoleName().equals("店长")) {
                            StaticData.personType = 0;
                        }
                        //将用户信息存储到本地
                        LocalData.saveUser(resultBean.getUser());
                        dismissDialog();
                        if (resultBean.getMerchant() == null) {
                            Bundle bundle = new Bundle();
                            bundle.putInt("pageStep", R.id.registerMaterialFragment);
                            startActivity(MerchantEnterActivity.class, bundle);
                        } else if (resultBean.getMerchant().getAuditStatus().equals("0")) {
                            Bundle bundle = new Bundle();
                            bundle.putInt("pageStep", R.id.merchantWaitFragment);
                            startActivity(MerchantEnterActivity.class, bundle);
                        } else {
                            LocalData.saveMerchant(resultBean.getMerchant());
                            startActivity(HomeActivity.class);
                        }
                      /*  LocalData.saveMerchant(resultBean.getMerchant());

                        startActivity(ProductManagerActivity.class);*/

                        finish();
                    }

                    @Override
                    public void onError(String Error) {
                        dismissDialog();
                    }


                });
    }


}


