package com.xx.merchanthbh.ui.phone;

import static me.goldze.mvvmhabit.utils.Utils.Interceptor_TOKEN;

import android.app.Application;
import android.text.TextUtils;
import android.util.Log;

import androidx.annotation.NonNull;
import androidx.databinding.ObservableField;

import com.xx.merchanthbh.data.http.requst.PhoneRequest;
import com.xx.merchanthbh.data.local.LocalData;
import com.xx.merchanthbh.ui.login.LoginActivity;
import com.xx.merchanthbh.ui.pwd.ForgetPwdViewModel;

import io.reactivex.rxjava3.disposables.Disposable;
import io.reactivex.rxjava3.functions.Consumer;
import me.goldze.mvvmhabit.base.BaseViewModel;
import me.goldze.mvvmhabit.binding.command.BindingAction;
import me.goldze.mvvmhabit.binding.command.BindingCommand;
import me.goldze.mvvmhabit.http.ApiDisposableObserver;
import me.goldze.mvvmhabit.utils.RxUtils;
import me.goldze.mvvmhabit.utils.ToastUtils;

public class PhoneViewModel extends BaseViewModel<PhoneRequest> {
    //当前绑定手机号
    public ObservableField<String> currentPhone = new ObservableField<>("");
    //更换的手机号
    public ObservableField<String> changePhoneNumber = new ObservableField<>("");
    //验证码
    public ObservableField<String> code = new ObservableField<>("");
    public PhoneViewModel(@NonNull Application application) {
        super(application);
    }

    public PhoneViewModel(@NonNull Application application, PhoneRequest model) {
        super(application, model);
    }
    /*设置当前绑定的手机号*/
    private void setValueToNickName() {
        currentPhone.set(LocalData.getUser().getPhonenumber());
        Log.v("当前绑定的手机号", String.valueOf(currentPhone.get()));
    }
    public void refreshNickName() {
        setValueToNickName();
    }

    // 获取验证码
    public BindingCommand getCode = new BindingCommand(new BindingAction() {
        @Override
        public void call() {

            if (TextUtils.isEmpty(currentPhone.get().toString())) {
                ToastUtils.showShort("请输入手机号！");
                return;
            }
            model.getCode(currentPhone.get())
                    .compose(RxUtils.schedulersTransformer()) //线程调度
                    .doOnSubscribe(PhoneViewModel.this)
                    .doOnSubscribe(new Consumer<Disposable>() {
                        @Override
                        public void accept(Disposable disposable) throws Exception {
                            showDialog("正在获取验证码");
                        }
                    }).subscribe(new ApiDisposableObserver<String>() {
                        @Override
                        public void onSuccess(String resultBean) {
                            ToastUtils.showShort("已经发送成功");
                            dismissDialog();
                        }

                        @Override
                        public void onError(String Error) {
                            dismissDialog();
                        }


                    });
        }
    });

    /*调用更改手机号接口*/
    // 触发确认按钮
    public BindingCommand changePhoneA = new BindingCommand(new BindingAction() {
        @Override
        public void call() {
            if (TextUtils.isEmpty(changePhoneNumber.get().toString())) {
                ToastUtils.showShort("请输入手机号！");
            } else if (TextUtils.isEmpty(code.get().toString())) {
                ToastUtils.showShort("请输入验证码！");
            } else {
                model.ChangePhone(changePhoneNumber.get().toString(), code.get().toString())
                        .compose(RxUtils.schedulersTransformer()) //线程调度
//                        .compose(RxUtils.exceptionTransformer()) // 网络错误的异常转换, 这里可以换成自己的ExceptionHandle
                        .doOnSubscribe(PhoneViewModel.this)
                        .doOnSubscribe(new Consumer<Disposable>() {
                            @Override
                            public void accept(Disposable disposable) throws Exception {
                                showDialog("正在请求...");
                            }
                        }).subscribe(new ApiDisposableObserver<String>() {
                            @Override
                            public void onSuccess(String resultBean) {
                                //是指token
                                Interceptor_TOKEN = "Bearer " + resultBean;
                                startActivity(LoginActivity.class);
                            }

                            @Override
                            public void onError(String Error) {
                                dismissDialog();
                            }

                        });
            }
        }
    });
}
